Crate scdsu_core

Crate scdsu_core 

Core library for steam-controller-dsu.

This library crate provides the ability to run CemuHook (DSU) server which supplies controller input state over a UDP connection to various video game console emulators. The main focus is supporting the Steam Controller 2026 (Triton).

Re-exports

pub use server::ServerConfig;

Modules

devices
Contains adapters from raw HID data to DSU frames for supported devices.
dsu
Provides functionality for working with DSU protocol data.
errors
Error types for the library.
reader
Provides a background reader for reading DSUFrame data from devices.
server
Provides the CemuHook (DSU) UDP server implementation.

Functions

run_debug_dump
Runs a debug loop, dumping DSU-compatible frames to stdout for debugging purposes. Like run_server, it runs until running is false.
run_server
Run the server loop until running is false.