pub struct DeviceConfig {
pub no_enable_lizard_mode_on_close: bool,
pub gyro_activation_inputs: Vec<DeviceButton>,
pub gyro_activation_mode: GyroActivationMode,
pub gyro_deadzone: f32,
pub gyro_pitch_scale: f32,
pub gyro_yaw_scale: f32,
pub gyro_roll_scale: f32,
}Expand description
Device configuration.
Defines configurable behavior within device adapters themselves.
For configuration affecting the behavior of the DSU server, see ‘ServerConfig’
Fields
no_enable_lizard_mode_on_close: boolDon’t enable lizard mode when the device is dropped (Triton)
gyro_activation_inputs: Vec<DeviceButton>Inputs that must be pressed to send gyro data through the DSU server.
gyro_activation_mode: GyroActivationModegyro_deadzone: f32Gyro deadzone in degrees per second. Values below this threshold are reported as zero.
gyro_pitch_scale: f32Scale factor applied to the pitch gyro axis.
gyro_yaw_scale: f32Scale factor applied to the yaw gyro axis.
gyro_roll_scale: f32Scale factor applied to the roll gyro axis.