pub struct Reader { /* private fields */ }Expand description
Background reader that continuously parses frames from a device
Implementations
Sourceimpl Reader
impl Reader
Sourcepub fn start(
running: Arc<AtomicBool>,
device: impl Device + Send + 'static,
) -> (Self, Receiver<DSUFrame>)
pub fn start( running: Arc<AtomicBool>, device: impl Device + Send + 'static, ) -> (Self, Receiver<DSUFrame>)
Spawn a thread that reads from device and sends parsed frames over the returned channel.
Returns immediately, use Reader::join to join the reader thread.
Returns Self and a mpsc Receiver for the UDP server