Server

Struct Server 

pub struct Server { /* private fields */ }
CemuHook UDP Server

Implementations

Source

impl Server

pub fn new( running: Arc<AtomicBool>, config: ServerConfig, ) -> Result<Self, ServerError>

Attempt to create a new Server.

The first argument is an AtomicBool within an Arc<> that, when false, signals that the server should be shut down.

pub fn run( &self, rx: Receiver<DSUFrame>, ) -> Result<(Result<()>, Result<(), Box<dyn Any + Send + 'static>>), ServerError>

Start the CemuHook UDP server and broadcast frames received on rx to all subscribed CemuHook clients Blocks until both the Receving loop (this thread) and Send loop (background thread) complete Returns both results on Success, Err(ServerError) if the server failed to start