Crate scdsu_core

Crate scdsu_core 

Core library for [steam-controller-dsu].

This crate is not intended to be used outside of the project. It could be, but it is not sufficiently documented.

Modules

errors

Structs

ServerConfig

Constants

READ_ATOMIC_BOOL_ORDERING

Functions

run_debug_dump
Run the debug loop. Attempts to open the controller and dump frames.
run_server
Run the server loop until receiving a signal