Core library for [steam-controller-dsu].
This crate is not intended to be used outside of the project. It could be, but it is not sufficiently documented.
Modules
Structs
Constants
Functions
- run_
debug_ dump - Run the debug loop. Attempts to open the controller and dump frames.
- run_
server - Run the server loop until receiving a signal